---
title: yaozarrs
---

::: yaozarrs
      options:
        show_bases: true
        summary: true
        heading_level: 2
        show_root_heading: true
        inherited_members: true
        summary: true

## Internal base classes

The following classes are internal base classes used by yaozarrs and are not
intended for direct import by users.  However, you may receive return objects
from yaozarrs functions and methods that are instances of these classes, so they
are documented here for completeness.

::: yaozarrs._zarr.ZarrNode
      options:
        heading_level: 3
        show_root_heading: true
        summary: false

::: yaozarrs._zarr.ZarrArray
      options:
        heading_level: 3
        show_root_heading: true
        show_bases: true
        summary: false
        merge_init_into_class: true
